==> larus_board-0.9.18.zip: larus_board-0.9.18/lb_private/config.style.default.php <==
<?php/*
[common]
name = "default"
author = "saturas"
version = "1.0.*"

[stylesheet]
css0 = "AUTO,screen|projection,{$URI_CSS}/default/0_base.css"
css1 = "AUTO,screen|projection,{$URI_CSS}/default/1_screen.css"
css2 = "AUTO,screen|projection,{$URI_CSS}/default/2_lang_{$LANGUAGE}.css"
css3 = "SKIP,screen|projection,{$URI_CSS}/default/3_user.css"
css4 = "CIE6,screen|projection,{$URI_CSS}/default/4_ie6fix.css"
css5 = "CIE7,screen|projection,{$URI_CSS}/default/4_ie7fix.css"

[imageset]
bbcode_anchor = "{$URI_GFX}/ext/media-skip-forward.png"
bbcode_anchor_big = "{$URI_GFX}/ext/media-skip-forward_32.png"
bbcode_bold = "{$URI_GFX}/ext/format-text-bold.png"
bbcode_code = "{$URI_GFX}/ext/text-x-script.png"
bbcode_code_big = "{$URI_GFX}/ext/text-x-script_32.png"
bbcode_embed = "{$URI_GFX}/ext/application-x-executable.png"
bbcode_format = "{$URI_GFX}/ext/preferences-desktop-wallpaper.png"
bbcode_img = "{$URI_GFX}/ext/image-x-generic.png"
bbcode_italic = "{$URI_GFX}/ext/format-text-italic.png"
bbcode_mail = "{$URI_GFX}/ext/internet-mail.png"
bbcode_notice = "{$URI_GFX}/ext/emblem-important.png"
bbcode_quote = "{$URI_GFX}/ext/internet-group-chat.png"
bbcode_quote_big = "{$URI_GFX}/ext/internet-group-chat_32.png"
bbcode_strikethrough = "{$URI_GFX}/ext/format-text-strikethrough.png"
bbcode_underline = "{$URI_GFX}/ext/format-text-underline.png"
bbcode_url = "{$URI_GFX}/ext/internet-web-browser.png"
bookmark = "{$URI_GFX}/ext/x-office-address-book.png"
icon_allow = "{$URI_GFX}/allow.png"
icon_delete = "{$URI_GFX}/ext/image-missing.png"
icon_deny = "{$URI_GFX}/deny.png"
icon_error = "{$URI_GFX}/ext/dialog-error.png"
icon_go_first = "{$URI_GFX}/ext/go-first.png"
icon_go_next = "{$URI_GFX}/ext/go-next.png"
icon_loading = "{$URI_GFX}/ext/ajax_loading.gif"
icon_preferences = "{$URI_GFX}/ext/preferences-system.png"
icon_refresh = "{$URI_GFX}/ext/view-refresh.png"
icon_sun = "{$URI_GFX}/ext/weather-clear.png"
icon_undo = "{$URI_GFX}/ext/edit-undo.png"
icon_warning = "{$URI_GFX}/ext/dialog-warning.png"
license_none = "{$URI_GFX}/license_none.png"
logo = "{$URI_GFX}/logo.png"
post_closed = "{$URI_GFX}/ext/emblem-readonly.png"
post_icon = "{$URI_GFX}/ext/text-x-generic.png"
post_icon_big = "{$URI_GFX}/ext/text-x-generic_32.png"
post_lastread = "{$URI_GFX}/ext/emblem-symbolic-link.png"
post_new = "{$URI_GFX}/ext/document-new.png"
post_rate_minus = "{$URI_GFX}/post_rate_minus_{$LANGUAGE}.png"
post_rate_plus = "{$URI_GFX}/post_rate_plus_{$LANGUAGE}.png"
post_user_involved = "{$URI_GFX}/user_involved.png"
rating_-10 = "{$URI_GFX}/rating_-10.png"
rating_-20 = "{$URI_GFX}/rating_-20.png"
rating_-30 = "{$URI_GFX}/rating_-30.png"
rating_-40 = "{$URI_GFX}/rating_-40.png"
rating_-50 = "{$URI_GFX}/rating_-50.png"
rating_-60 = "{$URI_GFX}/rating_-60.png"
rating_-70 = "{$URI_GFX}/rating_-70.png"
rating_-80 = "{$URI_GFX}/rating_-80.png"
rating_-90 = "{$URI_GFX}/rating_-90.png"
rating_-100 = "{$URI_GFX}/rating_-100.png"
rating_0 = "{$URI_GFX}/rating_0.png"
rating_10 = "{$URI_GFX}/rating_10.png"
rating_20 = "{$URI_GFX}/rating_20.png"
rating_30 = "{$URI_GFX}/rating_30.png"
rating_40 = "{$URI_GFX}/rating_40.png"
rating_50 = "{$URI_GFX}/rating_50.png"
rating_60 = "{$URI_GFX}/rating_60.png"
rating_70 = "{$URI_GFX}/rating_70.png"
rating_80 = "{$URI_GFX}/rating_80.png"
rating_90 = "{$URI_GFX}/rating_90.png"
rating_100 = "{$URI_GFX}/rating_100.png"
rss = "{$URI_GFX}/ext/rss.png"
search = "{$URI_GFX}/ext/edit-find.png"
search_previous_result = "{$URI_GFX}/ext/folder-saved-search.png"
user = "{$URI_GFX}/ext/system-users.png"
user_new = "{$URI_GFX}/user_new.png"
vcard = "{$URI_GFX}/ext/contact-new.png"
vcard_big = "{$URI_GFX}/ext/contact-new_22.png"
vote_negative = "{$URI_GFX}/vote_circle.png"
vote_positive = "{$URI_GFX}/vote_star.png"

*/?>

==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/config.style.default.php <==
;<?php/*
[common]
name = "default"
author = "saturas"
version = "1.1.*"

[stylesheet]
css0 = "AUTO,all,{$URI_CSS}/default/0_base.css"
css1 = "AUTO,screen|projection,{$URI_CSS}/default/1_screen.css"
css2 = "AUTO,braille|embossed|print,{$URI_CSS}/default/1_print.css"
css3 = "AUTO,screen|projection,{$URI_CSS}/default/2_lang_{$LANGUAGE}.css"
css4 = "JSIF,screen|projection,{$URI_CSS}/default/3_compact.css,window.innerWidth <= 800"
css5 = "SKIP,screen|projection,{$URI_CSS}/default/3_user.css"
css6 = "CIE6,screen|projection,{$URI_CSS}/default/4_ie6fix.css"
css7 = "CIE7,screen|projection,{$URI_CSS}/default/4_ie7fix.css"

[imageset]
bbcode_anchor = "{$URI_GFX}/ext/media-skip-forward.png"
bbcode_anchor_big = "{$URI_GFX}/ext/media-skip-forward_32.png"
bbcode_bold = "{$URI_GFX}/ext/format-text-bold.png"
bbcode_code = "{$URI_GFX}/ext/text-x-script.png"
bbcode_code_big = "{$URI_GFX}/ext/text-x-script_32.png"
bbcode_embed = "{$URI_GFX}/ext/application-x-executable.png"
bbcode_format = "{$URI_GFX}/ext/preferences-desktop-wallpaper.png"
bbcode_img = "{$URI_GFX}/ext/image-x-generic.png"
bbcode_italic = "{$URI_GFX}/ext/format-text-italic.png"
bbcode_mail = "{$URI_GFX}/ext/internet-mail.png"
bbcode_notice = "{$URI_GFX}/ext/emblem-important.png"
bbcode_quote = "{$URI_GFX}/ext/internet-group-chat.png"
bbcode_quote_big = "{$URI_GFX}/ext/internet-group-chat_32.png"
bbcode_strikethrough = "{$URI_GFX}/ext/format-text-strikethrough.png"
bbcode_underline = "{$URI_GFX}/ext/format-text-underline.png"
bbcode_url = "{$URI_GFX}/ext/internet-web-browser.png"
bookmark = "{$URI_GFX}/ext/x-office-address-book.png"
icon_allow = "{$URI_GFX}/allow.png"
icon_delete = "{$URI_GFX}/ext/image-missing.png"
icon_deny = "{$URI_GFX}/deny.png"
icon_error = "{$URI_GFX}/ext/dialog-error.png"
icon_go_first = "{$URI_GFX}/ext/go-first.png"
icon_go_next = "{$URI_GFX}/ext/go-next.png"
icon_loading = "{$URI_GFX}/ext/ajax_loading.gif"
icon_preferences = "{$URI_GFX}/ext/preferences-system.png"
icon_refresh = "{$URI_GFX}/ext/view-refresh.png"
icon_sun = "{$URI_GFX}/ext/weather-clear.png"
icon_undo = "{$URI_GFX}/ext/edit-undo.png"
icon_warning = "{$URI_GFX}/ext/dialog-warning.png"
license_none = "{$URI_GFX}/license_none.png"
logo = "{$URI_GFX}/logo.png"
post_closed = "{$URI_GFX}/ext/emblem-readonly.png"
post_icon = "{$URI_GFX}/ext/text-x-generic.png"
post_icon_big = "{$URI_GFX}/ext/text-x-generic_32.png"
post_lastread = "{$URI_GFX}/ext/emblem-symbolic-link.png"
post_new = "{$URI_GFX}/ext/document-new.png"
post_rate_minus = "{$URI_GFX}/post_rate_minus_{$LANGUAGE}.png"
post_rate_plus = "{$URI_GFX}/post_rate_plus_{$LANGUAGE}.png"
post_user_involved = "{$URI_GFX}/user_involved.png"
rating_-10 = "{$URI_GFX}/rating_-10.png"
rating_-20 = "{$URI_GFX}/rating_-20.png"
rating_-30 = "{$URI_GFX}/rating_-30.png"
rating_-40 = "{$URI_GFX}/rating_-40.png"
rating_-50 = "{$URI_GFX}/rating_-50.png"
rating_-60 = "{$URI_GFX}/rating_-60.png"
rating_-70 = "{$URI_GFX}/rating_-70.png"
rating_-80 = "{$URI_GFX}/rating_-80.png"
rating_-90 = "{$URI_GFX}/rating_-90.png"
rating_-100 = "{$URI_GFX}/rating_-100.png"
rating_0 = "{$URI_GFX}/rating_0.png"
rating_10 = "{$URI_GFX}/rating_10.png"
rating_20 = "{$URI_GFX}/rating_20.png"
rating_30 = "{$URI_GFX}/rating_30.png"
rating_40 = "{$URI_GFX}/rating_40.png"
rating_50 = "{$URI_GFX}/rating_50.png"
rating_60 = "{$URI_GFX}/rating_60.png"
rating_70 = "{$URI_GFX}/rating_70.png"
rating_80 = "{$URI_GFX}/rating_80.png"
rating_90 = "{$URI_GFX}/rating_90.png"
rating_100 = "{$URI_GFX}/rating_100.png"
rss = "{$URI_GFX}/ext/rss.png"
search = "{$URI_GFX}/ext/edit-find.png"
search_previous_result = "{$URI_GFX}/ext/folder-saved-search.png"
user = "{$URI_GFX}/ext/system-users.png"
user_new = "{$URI_GFX}/user_new.png"
vcard = "{$URI_GFX}/ext/contact-new.png"
vcard_big = "{$URI_GFX}/ext/contact-new_22.png"
vote_negative = "{$URI_GFX}/vote_circle.png"
vote_positive = "{$URI_GFX}/vote_star.png"
;*/?>
